@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2011-2012  Sebastián Marró <smarro@thymbra.com>
+#    Copyright (C) 2011-2014  Sebastián Marró <smarro@thymbra.com>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,10 +21,15 @@
 
 from trytond.pool import Pool
 from .health_calendar import *
+from .wizard import *
 
 
 def register():
     Pool.register(
-        Physician,
+        User,
         Appointment,
+        CreateAppointmentStart,
         module='health_calendar', type_='model')
+    Pool.register(
+        CreateAppointment,
+        module='health_calendar', type_='wizard')
